# SLY (Sly Lex-Yacc)
Original repo https://github.com/dabeaz/sly/tree/master

As per instructions in the sly repo. SLY is no longer supported as a pip installable, so packaging the source inside of this package to avoid breaking changes
